@@ -3,7 +3,7 @@
 /* Computes the mean field variational Bayes approximate logarithm of the
    marginal likelihood of the model corresponding to gamselBayesMFVBinnner. */
 
-/* Last changed: 06 APR 2023 */
+/* Last changed: 11 AUG 2023 */
 
 #include <RcppArmadillo.h>
 
@@ -12,11 +12,11 @@ using namespace Rcpp;
 
 //[[Rcpp::export]] 
 
-double approxLogML(double muqBetaZero, double sigsqqBeta0, arma::vec muqgammaBeta, double AqrhoBeta,
-                   double BqrhoBeta, double muqrecipSigsqBeta, arma::vec muqbBeta, arma::vec muqBetaTilde,
+double approxLogML(double muqBeta0, double sigsqqBeta0, double logitBeta, arma::vec muqgammaBeta, 
+                   double muqrecipSigsqBeta, arma::vec muqbBeta, arma::vec muqBetaTilde,
                    arma::mat SigmaqBetaTilde, double muqrecipaBeta, double lambdaqSigsqBeta,
-                   double sBetaHYP, double lambdaqaBeta, arma::mat muqgammaU, arma::vec AqrhoU,
-                   arma::vec BqrhoU, arma::vec muqrecipSigsqU, arma::vec muqbU,arma::mat muqUtilde,
+                   double sBetaHYP, double lambdaqaBeta, double logitU, arma::vec muqgammaU, 
+                   arma::vec muqrecipSigsqU, arma::vec muqbU,arma::mat muqUtilde,
                    arma::mat sigsqqUtilde, arma::vec muqrecipaU, arma::vec lambdaqSigsqU,
                    double sUHYP, arma::vec lambdaqaU, double muqrecipaEps, double muqrecipSigsqEps,
                    double lambdaqaEps, double lambdaqSigsqEps, double sEpsHYP, int n, arma::uvec ncZvec,
@@ -32,7 +32,9 @@ double approxLogML(double muqBetaZero, double sigsqqBeta0, arma::vec muqgammaBet
 
    /* Sequentially obtain the answer: */
 
-   answer = -0.5*(muqBetaZero*muqBetaZero + sigsqqBeta0) + 0.5*log(sigsqqBeta0); 
+   answer = -0.5*(muqBeta0*muqBeta0 + sigsqqBeta0) + 0.5*log(sigsqqBeta0);
+
+   answer = answer + logitBeta*sum(muqgammaBeta);
 
    for (int j=0; j<ncX; j++)
    {
@@ -40,8 +42,6 @@ double approxLogML(double muqBetaZero, double sigsqqBeta0, arma::vec muqgammaBet
       if (muqgammaBeta(j)<1.0) answer = answer - (1.0-muqgammaBeta(j))*log(1.0-muqgammaBeta(j)); 
    }
 
-   answer = answer + lgamma(AqrhoBeta) + lgamma(BqrhoBeta) - lgamma(AqrhoBeta + BqrhoBeta);
-
    sumCurr = 0.0;
    for (int j=0; j<ncX; j++)
       sumCurr = sumCurr + muqbBeta(j)*(muqBetaTilde(j)*muqBetaTilde(j) + SigmaqBetaTilde(j,j));
@@ -58,22 +58,20 @@ double approxLogML(double muqBetaZero, double sigsqqBeta0, arma::vec muqgammaBet
    answer = answer + muqrecipSigsqBeta*lambdaqSigsqBeta - muqrecipaBeta/(sBetaHYP*sBetaHYP);
    answer = answer + lambdaqaBeta*muqrecipaBeta - log(lambdaqaBeta);
 
+   answer = answer + logitU*sum(muqgammaU);
+   
    for (int j=0; j<dGeneral; j++)
    {
-      for (int k=0; k<ncZvec(j); k++)
-      {
-         if (muqgammaU(k,j)>0.0) answer = answer - muqgammaU(k,j)*log(muqgammaU(k,j));
-         if (muqgammaU(k,j)<1.0) answer = answer - (1.0-muqgammaU(k,j))*log(1.0-muqgammaU(k,j)); 
-      }
-
-      answer = answer + lgamma(AqrhoU(j)) + lgamma(BqrhoU(j)) - lgamma(AqrhoU(j) + BqrhoU(j));
+     
+      if (muqgammaU(j)>0.0) answer = answer - muqgammaU(j)*log(muqgammaU(j));
+      if (muqgammaU(j)<1.0) answer = answer - (1.0-muqgammaU(j))*log(1.0-muqgammaU(j)); 
 
       answer = answer - 0.5*muqrecipSigsqU(j)*muqbU(j)*(sum(muqUtilde.col(j)%muqUtilde.col(j)) 
                                                         + sum(sigsqqUtilde.col(j)));
       for (int k=0; k<ncZvec(j); k++)
          answer = answer + 0.5*log(sigsqqUtilde(k,j));
 
-      answer = answer - 0.5/muqbU(j) + muqrecipaU(j)*muqrecipSigsqU(j);
+      answer = answer - 0.5/muqbU(j) - muqrecipaU(j)*muqrecipSigsqU(j);
       answer = answer - 0.5*(ncZvec(j) + 1.0)*log(lambdaqSigsqU(j));
       answer = answer + muqrecipSigsqU(j)*lambdaqSigsqU(j) - muqrecipaU(j)/(sUHYP*sUHYP);
       answer = answer + lambdaqaU(j)*muqrecipaU(j) - log(lambdaqaU(j));      
@@ -81,8 +79,7 @@ double approxLogML(double muqBetaZero, double sigsqqBeta0, arma::vec muqgammaBet
 
    if (familyNum==1)
    {
-      answer = answer + muqrecipaEps*muqrecipSigsqEps - 0.5*(n+1)*log(lambdaqSigsqEps);
-      answer = answer + muqrecipSigsqEps*lambdaqSigsqEps - muqrecipaEps/(sEpsHYP*sEpsHYP);
+      answer = answer - 0.5*(n+1)*log(lambdaqSigsqEps) - muqrecipaEps/(sEpsHYP*sEpsHYP);
       answer = answer - log(lambdaqaEps) + lambdaqaEps*muqrecipaEps;
    }
 
@@ -91,7 +88,7 @@ double approxLogML(double muqBetaZero, double sigsqqBeta0, arma::vec muqgammaBet
       for (int i=0; i<n; i++)
          answer = answer + logPhi(ySign(i)*omega20(i));
    }
-
+   
    /* Return the approximate marginal log-likelihood: */
                                                
    return answer;
